@@ -15,7 +15,7 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 __license__ = 'GPLv3'
-__version__ = '1.1.0'
+__version__ = '1.1.2'
 
 run_help = '''TBlock - An anticapitalist ad-blocker that uses the hosts file
 Copyright (c) 2021 Twann <twann@ctemplar.com>
@@ -52,7 +52,7 @@ usage: tblock <operation> <options>
 * General options
   -f  --force                             Do not prompt user for anything
 * Filters options
-  -y  --sync                              Update remote filters repository
+  -y  --with-sync                         Update remote filters repository
 * List options
   -t  --standard                          Only show standard rules
   -u  --user                              Only show user rules
