@@ -65,7 +65,7 @@ tblock_opts = [
     '-f', '--force',
     '-t', '--standard',
     '-u', '--user',
-    '-y', '--sync',
+    '-y', '--with-sync',
     '-c', '--custom',
     '-k', '--subscribing',
     '-n', '--unsubscribing',
@@ -100,7 +100,7 @@ class TBlockArguments:
             'standard': False,
             'user': False,
             'custom': False,
-            'sync': False,
+            'with-sync': False,
             'subscribing': False,
             'unsubscribing': False,
             'on-remote-repo': False
@@ -306,35 +306,35 @@ def parse_args_tblock() -> None:
         data = []
         for filter_id in parser.values:
             data.append([filter_id, 'b'])
-        subscribe_to_filters(data, parser.options['force'])
-        if parser.options['sync']:
-            print()
+        if parser.options['with-sync']:
             sync_remote_repo(parser.options['force'])
+            print()
+        subscribe_to_filters(data, parser.options['force'])
 
     elif parser.action == 'add-custom':
         data = []
         for filter_id in parser.values:
             data.append([filter_id, 'b', os.path.realpath(parser.values[parser.values.index(filter_id) + 1])])
             parser.values.pop(parser.values.index(filter_id) + 1)
-        subscribe_to_filters(data, parser.options['force'])
-        if parser.options['sync']:
-            print()
+        if parser.options['with-sync']:
             sync_remote_repo(parser.options['force'])
+            print()
+        subscribe_to_filters(data, parser.options['force'])
 
     elif parser.action == 'remove':
-        unsubscribe_from_filters(parser.values, parser.options['force'])
-        if parser.options['sync']:
-            print()
+        if parser.options['with-sync']:
             sync_remote_repo(parser.options['force'])
+            print()
+        unsubscribe_from_filters(parser.values, parser.options['force'])
 
     elif parser.action == 'update':
+        if parser.options['with-sync']:
+            sync_remote_repo(parser.options['force'])
+            print()
         if parser.values:
             update_filters(parser.values, parser.options['force'])
         else:
             update_all_filters(parser.options['force'])
-        if parser.options['sync']:
-            print()
-            sync_remote_repo(parser.options['force'])
 
     elif parser.action == 'search':
         for query in parser.values:
@@ -347,10 +347,10 @@ def parse_args_tblock() -> None:
             permissions = parser.values[0]
             for filter_id in parser.values[1:]:
                 data.append([filter_id, permissions])
-            change_filters_permissions(data, parser.options['force'])
-            if parser.options['sync']:
-                print()
+            if parser.options['with-sync']:
                 sync_remote_repo(parser.options['force'])
+                print()
+            change_filters_permissions(data, parser.options['force'])
         except IndexError:
             if not check_root():
                 raise PermissionError(
@@ -367,15 +367,15 @@ def parse_args_tblock() -> None:
                 f'{Fore.RED}ERROR: you need to run as root to perform this operation{Style.RESET_ALL}')
         if len(parser.values) > 2:
             raise IOError(f'{Fore.RED}ERROR: too much arguments are given for changing filter ID{Style.RESET_ALL}')
+        if parser.options['with-sync']:
+            sync_remote_repo(parser.options['force'])
+            print()
         try:
             change_filter_id(parser.values[0], parser.values[1])
         except IndexError:
             raise MissingArgumentError(
                 f'{Fore.RED}ERROR: you need to specify the filter to rename as well as its new ID{Style.RESET_ALL}'
             )
-        if parser.options['sync']:
-            print()
-            sync_remote_repo(parser.options['force'])
 
     elif parser.action == 'info':
         show_filters(parser.values)
@@ -447,8 +447,8 @@ def run() -> None:
         parse_args_tblock()
     except (PermissionError, FilterSourceExistsError, MissingArgumentError, FilterNotExists, NotSubscribingError,
             RuleNotExistsError, InvalidBindAddress, InvalidFilterSyntax, FileNotFoundError, NetworkError,
-            FilterExistsError, FilterNotCustomError) as err:
-        print(str(err).replace('[Errno 2] N', 'n'))
+            FilterExistsError, FilterNotCustomError, IsADirectoryError) as err:
+        print(str(err).replace('[Errno 2] N', 'n').replace('[Errno 21] I', 'i'))
         unlock_database()
         sys.exit(1)
     except sqlite3.OperationalError:
@@ -468,8 +468,8 @@ def run_converter() -> None:
     try:
         parse_args_tblockc()
     except (PermissionError, FilterSourceExistsError, MissingArgumentError, FilterNotExists, NotSubscribingError,
-            RuleNotExistsError, InvalidBindAddress, InvalidFilterSyntax, FileNotFoundError) as err:
-        print(str(err).replace('[Errno 2] N', 'n'))
+            RuleNotExistsError, InvalidBindAddress, InvalidFilterSyntax, FileNotFoundError, IsADirectoryError) as err:
+        print(str(err).replace('[Errno 2] N', 'n').replace('[Errno 21] I', 'i'))
         sys.exit(1)
     except (SIGTERM, KeyboardInterrupt):
         exit(1)
