@@ -122,6 +122,7 @@ class Filter:
                     raise FilterSourceExistsError(f'the source "{source}" is already the source of another filter')
                 else:
                     self.source = source
+                    self.update(verbosity=False, subscribing_operation=True)
                     print(f' [{Fore.YELLOW}|{Style.RESET_ALL}] Marking filter as subscribed in database', end='\r')
                     with sqlite3.connect(Path.DATABASE) as conn:
                         conn.cursor().execute(
@@ -141,6 +142,7 @@ class Filter:
                 if self.subscribing:
                     raise AlreadySubscribingError(f'you are already subscribing to filter: "{self.id}"')
                 else:
+                    self.update(verbosity=False, subscribing_operation=True)
                     print(f' [{Fore.YELLOW}|{Style.RESET_ALL}] Marking filter as subscribed in database', end='\r')
                     with sqlite3.connect(Path.DATABASE) as conn:
                         conn.cursor().execute(
@@ -234,15 +236,16 @@ class Filter:
             )
         self.update(False)
 
-    def update(self, verbosity: bool = True) -> None:
+    def update(self, verbosity: bool = True, subscribing_operation: bool = False) -> None:
         """Update rules from a filter
 
         Args:
             verbosity (bool, optional): Display info about what is happening (default)
+            subscribing_operation (bool, optional): The subscribing operation is in progress
         """
-        if not self.exists:
+        if not self.exists and not subscribing_operation:
             raise FilterNotExists(f'the filter "{self.id}" does not exist or is not available')
-        elif not self.subscribing:
+        elif not self.subscribing and not subscribing_operation:
             raise NotSubscribingError(f'you are not subscribing to filter "{self.id}"')
         if verbosity:
             print(f'{Font.BOLD}==> Updating filter: {self.id}{Font.DEFAULT}')
@@ -520,12 +523,12 @@ def subscribe_to_filters(filters: list, force: bool = False) -> None:
                 print(f'{Fore.YELLOW}WARNING: {err}{Style.RESET_ALL}')
             except (FilterSourceExistsError, FilterExistsError) as err:
                 raise FilterSourceExistsError(f'{Fore.RED}ERROR: {err}{Style.RESET_ALL}')
-            try:
-                filter_obj.update(False)
             except InvalidFilterSyntax as err:
                 raise InvalidFilterSyntax(f'{Fore.RED}ERROR: {err}{Style.RESET_ALL}')
             except FileNotFoundError as err:
                 raise FileNotFoundError(f'{Fore.RED}ERROR: {err}{Style.RESET_ALL}')
+            except IsADirectoryError as err:
+                raise IsADirectoryError(f'{Fore.RED}ERROR: {err}{Style.RESET_ALL}')
         update_hosts(get_all_rules())
         unlock_database()
     except PermissionError:
@@ -565,6 +568,8 @@ def change_filters_permissions(filters: list, force: bool = False) -> None:
                 raise InvalidFilterSyntax(f'{Fore.RED}ERROR: {err}{Style.RESET_ALL}')
             except FileNotFoundError as err:
                 raise FileNotFoundError(f'{Fore.RED}ERROR: {err}{Style.RESET_ALL}')
+            except IsADirectoryError as err:
+                raise IsADirectoryError(f'{Fore.RED}ERROR: {err}{Style.RESET_ALL}')
         update_hosts(get_all_rules())
         unlock_database()
     except PermissionError:
@@ -606,16 +611,17 @@ def unsubscribe_from_filters(filters: list, force: bool = False) -> None:
         pass
 
 
-def update_filters(filters: list, force: bool = False) -> None:
+def update_filters(filters: list, force: bool = False, subscribing_operation: bool = False) -> None:
     """Update rules from a list of filters
 
     Args:
         filters (list): All filters ID in a list: [id_1, id_2]
         force (bool, optional): Do not prompt user (False by default)
+        subscribing_operation (bool, optional): The subscribing operation is in progress
     """
     list_id = []
     for filter_id in filters:
-        if not Filter(filter_id).subscribing:
+        if not Filter(filter_id).subscribing and not subscribing_operation:
             raise NotSubscribingError(f'{Fore.RED}ERROR: not subscribing to filter: {filter_id}{Style.RESET_ALL}')
         list_id.append(filter_id)
     if not check_root():
@@ -635,6 +641,8 @@ def update_filters(filters: list, force: bool = False) -> None:
                 raise InvalidFilterSyntax(f'{Fore.RED}ERROR: {err}{Style.RESET_ALL}')
             except FileNotFoundError as err:
                 raise FileNotFoundError(f'{Fore.RED}ERROR: {err}{Style.RESET_ALL}')
+            except IsADirectoryError as err:
+                raise IsADirectoryError(f'{Fore.RED}ERROR: {err}{Style.RESET_ALL}')
         update_hosts(get_all_rules())
         unlock_database()
     except PermissionError:
