@@ -38,20 +38,14 @@ class TestSubscribeFilters(unittest.TestCase):
             None
         )
 
-    def test_subscribe_to_unsupported_filetype_remove(self):
-        try:
-            os.remove(tblock.config.Path.DB_LOCK)
-        except FileNotFoundError:
-            pass
-        self.assertEquals(
-            filters.unsubscribe_from_filters(['test-filter-error'], force=True),
-            None
-        )
-
 
 class TestSubscribingChangeID(unittest.TestCase):
 
     def test_change_filter_id(self):
+        try:
+            os.remove(tblock.config.Path.DB_LOCK)
+        except FileNotFoundError:
+            pass
         self.assertEquals(
             filters.change_filter_id('test-filter', 'test-filter2', force=True),
             None
